--------------------------------------------------------------------------------
-- Company:
-- Engineer:
--
-- Create Date:    15:53:50 05/08/05
-- Design Name:
-- Module Name:    bus_ctrl - Behavioral
-- Project Name:
-- Target Device:
-- Tool versions:
-- Description:
--
-- Dependencies:
--
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
--
------------------------------------------------------------
-- Data and Instruction RAM 	== 00000000 - 000000FF
-- Character RAM		== 00001000 - 000019FF
-- Font RAM			== 00002000 - 000025FF
------------------------------------------------------------

--------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
library UNISIM;
use UNISIM.VComponents.all;

library work;
use work.pack_mips.all;

entity bus_ctrl is
port
(
    clock : std_logic;
    reset : std_logic;

    -- Interruption in the pipeline
    interrupt      : in std_logic;

    -- Interface for the Instruction Extraction Stage
    adr_from_ei    : in bus32;      -- The address of the data to read
    instr_to_ei    : out bus32;     -- Instruction from the memory

    -- Interface with the MEMory Stage
    req_from_mem   : in std_logic;  -- Request to access the ram
    r_w_from_mem   : in std_logic;  -- Read/Write request
    adr_from_mem   : in bus32;      -- Address in ram
    data_from_mem  : in bus32;      -- Data to write in ram
    data_to_mem    : out bus32;     -- Data from the ram to the MEMory stage

    load_to_video  : out std_logic;
    vsync_to_video : out std_logic;
    hsync_to_video : out std_logic;
    blank_to_video : out std_logic;
    byte_to_video  : out bus8;

    -- Pipeline progress control signal
    stop_all       : in std_logic
);

end bus_ctrl;

architecture Behavioral of bus_ctrl is


------------------------------------------------------------
-- Data and Instruction RAM 	== 00000000 - 000000FF
-- Character RAM		== 00001000 - 000019FF
-- Font RAM			== 00002000 - 000025FF
------------------------------------------------------------


constant videoShiftLoad : bus32 := X"00004000"; -- Addresses to send signal
constant videoBLANK     : bus32 := X"00004001";	-- to video controller
constant videoHSYNC     : bus32 := X"00004002";
constant videoVSYNC     : bus32 := X"00004003";
constant videoHandVSYNC : bus32 := X"00004004";


signal data_out_to_mem, char_out_to_mem : bus32 := X"00000000";
signal data_out_to_ei : bus32;
signal char_out_to_mem0, char_out_to_mem1, char_out_to_mem2 : bus8 := X"00";
signal char_out_to_mem3, char_out_to_mem4 : bus8 := X"00";
signal dataRAM_RST, instrRAM_RST : std_logic := '1';
signal charRAM_RST : bus5 := "11111";
signal fontRAM_RST : std_logic_vector (2 downto 0) := "111";
signal dataRAM_WE : std_logic := '0';
signal charRAM_WE : bus5 := "00000";
--signal fontRAM_WE : std_logic_vector(2 downto 0) := "000";
signal real_adr_from_mem : bus32;
signal font_adr : std_logic_vector(8 downto 0);
signal font_in, font_out0, font_out1, font_out2 : bus8 := X"00";


 component RAMB4_S8
  -- Initialize the RAM (xapp173.pdf)
-- synopsis translate on
	 generic( 	INIT_00, INIT_01, INIT_02, INIT_03,
			INIT_04, INIT_05, INIT_06, INIT_07,
			INIT_08, INIT_09, INIT_0a, INIT_0b,
			INIT_0c, INIT_0d, INIT_0e,
			INIT_0f : BIT_VECTOR(255 downto 0) :=
		X"0000000000000000000000000000000000000000000000000000000000000000");
-- synopsis translate off
    port (
      DO   : out std_logic_vector(7 downto 0);
      ADDR : in  std_logic_vector(8 downto 0);
      CLK  : in  std_logic;
      DI   : in  std_logic_vector(7 downto 0);
      EN   : in  std_logic;
      RST  : in  std_logic;
      WE   : in  std_logic);
  end component;


   component RAMB4_S16_S16
	-- synopsis translate on
	 generic( 	INIT_00, INIT_01, INIT_02, INIT_03,
			INIT_04, INIT_05, INIT_06, INIT_07,
			INIT_08, INIT_09, INIT_0a, INIT_0b,
			INIT_0c, INIT_0d, INIT_0e,
			INIT_0f : BIT_VECTOR(255 downto 0) :=
		X"0000000000000000000000000000000000000000000000000000000000000000");
	-- synopsis translate off
    port (
      DOA   : out std_logic_vector (15 downto 0);
      ADDRA : in std_logic_vector (7 downto 0);
      CLKA  : in std_logic;
      DIA   : in std_logic_vector (15 downto 0);
      ENA   : in std_logic;
      RSTA  : in std_logic;
      WEA   : in std_logic;
      DOB   : out std_logic_vector (15 downto 0);
      ADDRB : in std_logic_vector (7 downto 0);
      CLKB  : in std_logic;
      DIB   : in std_logic_vector (15 downto 0);
      ENB   : in std_logic;
      RSTB  : in std_logic;
      WEB   : in std_logic);
  end component;


begin

instrRAM_RST <= adr_from_ei(15) OR adr_from_ei(14) when adr_from_ei(31 downto 16) = X"0000" else
					 '1';
real_adr_from_mem <= adr_from_mem;-- when r_w_from_mem = '1' else
--		     ("00" & adr_from_mem(31 downto 2));

char_out_to_mem <= X"000000" & (char_out_to_mem0 or char_out_to_mem1 or char_out_to_mem2 or char_out_to_mem3 or char_out_to_mem4);

dataRAM_WE 	<=  not dataRAM_RST and r_w_from_mem;
charRAM_WE(0) 	<= (not charRAM_RST(0)) and r_w_from_mem;
charRAM_WE(1) 	<= (not charRAM_RST(1)) and r_w_from_mem;
charRAM_WE(2) 	<= (not charRAM_RST(2)) and r_w_from_mem;
charRAM_WE(3) 	<= (not charRAM_RST(3)) and r_w_from_mem;
charRAM_WE(4) 	<= (not charRAM_RST(4)) and r_w_from_mem;

font_in <= data_from_mem(7 downto 0) - X"20";
font_adr <= font_in(4 downto 0) & real_adr_from_mem(3 downto 0) when stop_all = '0';--font_in(4 downto 0) &  real_adr_from_mem(3 downto 0);


process (real_adr_from_mem, req_from_mem, reset)
begin
    charRAM_RST <= "11111";
    dataRAM_RST <= '1';
    if reset = '0' then
        if req_from_mem = '1' then
            if real_adr_from_mem(31 downto 16) = X"0000" then
                case real_adr_from_mem(15 downto 9) is
                    when "0000000" =>
                        dataRAM_RST <= '0';
                    when "0001000" =>
                        charRAM_RST(0) <= '0';
                    when "0001001" =>
                        charRAM_RST(1) <= '0';
                    when "0001010" =>
                        charRAM_RST(2) <= '0';
                    when "0001011" =>
                        charRAM_RST(3) <= '0';
                    when "0001100" =>
                        charRAM_RST(4) <= '0';
                    when others =>
                        charRAM_RST <= "11111";
                        dataRAM_RST <= '1';
                end case;
            end if;
        end if;
    end if;
end process;


-- Decode the font address and font data
process (real_adr_from_mem, font_in, reset)
begin
    fontRAM_RST <= "111";
    if reset = '0' then
        if real_adr_from_mem(31 downto 4) = X"0000200" then
            case font_in(7 downto 5) is
                when "000" =>
                    fontRAM_RST(0) <= '0';
                when "001" =>
                    fontRAM_RST(1) <= '0';
                when "010" =>
                    fontRAM_RST(2) <= '0';
                when others =>
                    fontRAM_RST <= "111";
            end case;
        end if;
   end if;
end process;

process (real_adr_from_mem, stop_all, clock)
begin
   if stop_all = '0' and clock = '1' and clock'event then
    load_to_video  <= '0';
    vsync_to_video <= '0';
    hsync_to_video <= '0';
    blank_to_video <= '0';
    

    case real_adr_from_mem is
        when videoShiftLoad =>
            load_to_video <= '1';
        when videoBLANK =>
            blank_to_video <= '1';
        when videoHSYNC =>
            hsync_to_video <= '1';
        when videoVSYNC =>
            vsync_to_video <= '1';
        when videoHandVSYNC =>
            vsync_to_video <= '1';
            hsync_to_video <= '1';
        when others =>
    end case;
   end if;    
   
end process;

--------------------------------------------------
-- For a bigger size RAM, we will use 8 1k x 4	--
-- BRAMs to emulate a 1k x 32 RAM		--
--------------------------------------------------
-- If we need less memory, we could go with 	--
-- 4 512 x 8, or 2 256 x 16			--
-- for a 2k x 32, we could use 16 2k x 2 BRAMs	--
-- I'm not sure if there are 16 available, though-
--------------------------------------------------

------------------------------------------------------------
-- Data and Instruction RAM  == 00000000 - 000000FF
------------------------------------------------------------

dataRAM_0 : RAMB4_S16_S16
-- synopsis translate on
generic map( INIT_00 => X"AC00201F1C00201F0000AC00201FAC00201FAC00201FAC00201FAC00201F2014",
             INIT_01 => X"AC00AC62201F8C68000000740020AC00201FAC00201F00000000144028222021",
             INIT_02 => X"2825202114A028452042AC00201F201F14A028852084AC62201F8C6820632004",
             INIT_03 => X"000000000000000000000000000014A028252021AC00201FAC00201F200114A0")
-- synopsis translate off
port map( DOA   => data_out_to_ei(31 downto 16),
          ADDRA => adr_from_ei(9 downto 2),
          CLKA  => clock,
          DIA   => X"0000",
          ENA   => '1',
          RSTA  => instrRAM_RST,
          WEA   => '0',                      -- always reads
          DOB 	=> data_out_to_mem(31 downto 16),
          ADDRB => real_adr_from_mem(7 downto 0),
          CLKB  => clock,
          DIB   => data_from_mem(31 downto 16),
          ENB   => '1',
          RSTB  => dataRAM_RST,
          WEB   => dataRAM_WE);

dataRAM_1 : RAMB4_S16_S16
-- synopsis translate on
generic map(  INIT_00 => X"40020060400202C00820400400064002000C400200064002000C40040006001E",
              INIT_01 => X"40014000000810001812001818204002002F4002006010200820FFFA001F0001",
              INIT_02 => X"001E0001FFE800100001400100100001FFFA0050000140000008100000010000",
              INIT_03 => X"0000000000000000000000000000FFC8000A0001400202C0400200600000FFE4")
-- synopsis translate off
port map( DOA   => data_out_to_ei(15 downto 0),
          ADDRA => adr_from_ei(9 downto 2),
          CLKA  => clock,
          DIA   => X"0000",
          ENA   => '1',
          RSTA  => instrRAM_RST,
          WEA   => '0',                      --always reads
          DOB 	=> data_out_to_mem(15 downto 0),
          ADDRB => real_adr_from_mem(7 downto 0),
          CLKB  => clock,
          DIB   => data_from_mem(15 downto 0),
          ENB   => '1',
          RSTB  => dataRAM_RST,
          WEB   => dataRAM_WE);


------------------------------------------------------------
-- Character RAM  == 00001000 - 000019FF
------------------------------------------------------------

CHAR_RAM_0 : RAMB4_S8
-- synopsis translate on
generic map(  INIT_00 => X"326e616d32656874326c696d4532323232323232323232323232323232323232")
-- synopsis translate off
port map ( DO   => char_out_to_mem0,
           ADDR => real_adr_from_mem(8 downto 0),
           CLK  => clock,
           DI   => data_from_mem(7 downto 0),
           EN   => '1',
           RST  => charRAM_RST(0),
           WE   => charRAM_WE(0));

CHAR_RAM_1 : RAMB4_S8
-- synopsis translate on
generic map(  INIT_00 => X"b7309e101818001818183c3c3c18000000000000000000000000000000000000")
-- synopsis translate off
port map ( DO   => char_out_to_mem1,
           ADDR => real_adr_from_mem(8 downto 0),
           CLK  => clock,
           DI   => data_from_mem(7 downto 0),
           EN   => '1',
           RST  => charRAM_RST(1),
           WE   => charRAM_WE(1));

CHAR_RAM_2 : RAMB4_S8
-- synopsis translate on
--generic map(  INIT_00 => X"b7309e101818001818183c3c3c18000000000000000000000FEDCBA987654321")
-- synopsis translate off
port map ( DO   => char_out_to_mem2,
           ADDR => real_adr_from_mem(8 downto 0),
           CLK  => clock,
           DI   => data_from_mem(7 downto 0),
           EN   => '1',
           RST  => charRAM_RST(2),
           WE   => charRAM_WE(2));

CHAR_RAM_3 : RAMB4_S8
-- synopsis translate on
--generic map(  INIT_00 => X"b7309e101818001818183c3c3c18000000000000000000000FEDCBA987654321")
-- synopsis translate off
port map ( DO   => char_out_to_mem3,
           ADDR => real_adr_from_mem(8 downto 0),
           CLK  => clock,
           DI   => data_from_mem(7 downto 0),
           EN   => '1',
           RST  => charRAM_RST(3),
           WE   => charRAM_WE(3));

CHAR_RAM_4 : RAMB4_S8
-- synopsis translate on
--generic map(  INIT_00 => X"b7309e101818001818183c3c3c18000000000000000000000FEDCBA987654321")
-- synopsis translate off
port map ( DO   => char_out_to_mem4,
           ADDR => real_adr_from_mem(8 downto 0),
           CLK  => clock,
           DI   => data_from_mem(7 downto 0),
           EN   => '1',
           RST  => charRAM_RST(4),
           WE   => charRAM_WE(4));


------------------------------------------------------------
-- Font RAM  == 00002000 - 000025FF
------------------------------------------------------------

FONT_RAM_0 : RAMB4_S8
-- synopsis translate on
generic map(  INIT_00 => X"000000001818001818183c3c3c18000000000000000000000000000000000000",
              INIT_01 => X"000000006c6cfe6c6c6cfe6c6c00000000000000000000000000002466666600",
              INIT_02 => X"0000000086c66030180cc6c200000000000010107cd616167cd0d0d67c101000",
              INIT_03 => X"000000000000000000000030181818000000000076ccccccdc76386c6c380000",
              INIT_04 => X"0000000030180c0c0c0c0c0c18300000000000000c18303030303030180c0000",
              INIT_05 => X"00000000000018187e18180000000000000000000000663cff3c660000000000",
              INIT_06 => X"0000000000000000fe0000000000000000000030181818000000000000000000",
              INIT_07 => X"0000000000c06030180c06000000000000000000181800000000000000000000",
              INIT_08 => X"000000007e1818181818187838180000000000007cc6e6e6d6d6cecec67c0000",
              INIT_09 => X"000000007cc60606063c0606c67c000000000000fec6c06030180c06c67c0000",
              INIT_0a => X"000000007cc6060606fcc0c0c0fe0000000000001e0c0c0cfecc6c3c1c0c0000",
              INIT_0b => X"0000000030303030180c0606c6fe0000000000007cc6c6c6c6fcc0c060380000",
              INIT_0c => X"00000000780c0606067ec6c6c67c0000000000007cc6c6c6c67cc6c6c67c0000",
              INIT_0d => X"0000000030181800000018180000000000000000001818000000181800000000",
              INIT_0e => X"00000000000000fe0000fe000000000000000000060c18306030180c06000000",
              INIT_0f => X"000000001818001818180cc6c67c0000000000006030180c060c183060000000")
-- synopsis translate off
port map ( DO   => font_out0,
           ADDR => font_adr,
           CLK  => clock,
           DI   => font_in,
           EN   => '1',
           RST  => fontRAM_RST(0),
           WE   => '0');

FONT_RAM_1 : RAMB4_S8
-- synopsis translate on
generic map(  INIT_00 => X"00000000c6c6c6c6fec6c66c38100000000000007cc0dcdededec6c6c67c0000",
              INIT_01 => X"000000003c66c2c0c0c0c0c2663c000000000000fc666666667c666666fc0000",
              INIT_02 => X"00000000fe6662606878686266fe000000000000f86c6666666666666cf80000",
              INIT_03 => X"000000003a66c6c6dec0c0c2663c000000000000f06060606878686266fe0000",
              INIT_04 => X"000000003c18181818181818183c000000000000c6c6c6c6c6fec6c6c6c60000",
              INIT_05 => X"00000000e666666c78786c6666e600000000000078cccccc0c0c0c0c0c1e0000",
              INIT_06 => X"00000000c6c6c6c6c6d6fefeeec6000000000000fe6662606060606060f00000",
              INIT_07 => X"000000007cc6c6c6c6c6c6c6c67c000000000000c6c6c6c6cedefef6e6c60000",
              INIT_08 => X"00000e0c7cded6c6c6c6c6c6c67c000000000000f0606060607c666666fc0000",
              INIT_09 => X"000000007cc6c6060c3860c6c67c000000000000e66666666c7c666666fc0000",
              INIT_0a => X"000000007cc6c6c6c6c6c6c6c6c60000000000003c1818181818185a7e7e0000",
              INIT_0b => X"000000006ceefed6d6d6c6c6c6c600000000000010386cc6c6c6c6c6c6c60000",
              INIT_0c => X"000000003c181818183c66666666000000000000c6c66c7c38387c6cc6c60000",
              INIT_0d => X"000000003c30303030303030303c000000000000fec6c26030180c86c6fe0000",
              INIT_0e => X"000000003c0c0c0c0c0c0c0c0c3c00000000000000060c183060c00000000000",
              INIT_0f => X"00ff0000000000000000000000000000000000000000000000000000c66c3810")
-- synopsis translate off
port map ( DO   => font_out1,
           ADDR => font_adr,
           CLK  => clock,
           DI   => font_in,
           EN   => '1',
           RST  => fontRAM_RST(1),
           WE   => '0');

FONT_RAM_2 : RAMB4_S8
-- synopsis translate on
generic map(  INIT_00 => X"0000000076cccccc7c0c78000000000000000000000000000000001830303000",
              INIT_01 => X"000000007cc6c0c0c0c67c0000000000000000007c666666666c786060e00000",
              INIT_02 => X"000000007cc6c0c0fec67c00000000000000000076cccccccc6c3c0c0c1c0000" ,
              INIT_03 => X"0078cc0c7ccccccccccc76000000000000000000f060606060f060646c380000" ,
              INIT_04 => X"000000003c181818181838001818000000000000e666666666766c6060e00000" ,
              INIT_05 => X"00000000e6666c78786c666060e00000003c66660606060606060e0006060000" ,
              INIT_06 => X"00000000c6d6d6d6d6feec000000000000000000183430303030303030700000" ,
              INIT_07 => X"000000007cc6c6c6c6c67c000000000000000000666666666666dc0000000000" ,
              INIT_08 => X"001e0c0c7ccccccccccc76000000000000f060607c6666666666dc0000000000" ,
              INIT_09 => X"000000007cc60c3860c67c000000000000000000f06060606676dc0000000000" ,
              INIT_0A => X"0000000076cccccccccccc0000000000000000001c3630303030fc3030100000" ,
              INIT_0B => X"000000006cfed6d6d6c6c6000000000000000000183c66666666660000000000" ,
              INIT_0C => X"00f80c067ec6c6c6c6c6c6000000000000000000c66c3838386cc60000000000" ,
              INIT_0D => X"000000000e18181818701818180e000000000000fec6603018ccfe0000000000" ,
              INIT_0E => X"0000000070181818180e18181870000000000000181818181818181818180000" ,
              INIT_0F => X"000000003c1818183c66666666006600000000000000000000000000dc760000")
-- synopsis translate off
port map ( DO   => font_out2,
           ADDR => font_adr,
           CLK  => clock,
           DI   => font_in,
           EN   => '1',
           RST  => fontRAM_RST(2),
           WE   => '0');

instr_to_ei <= data_out_to_ei;
data_to_mem <= data_out_to_mem OR char_out_to_mem;
byte_to_video <= font_out0 or font_out1 or font_out2;

end Behavioral;
