library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
library UNISIM;
use UNISIM.VComponents.all;
library work;
use work.pack_mips.all;
USE IEEE.STD_LOGIC_TEXTIO.ALL;
USE STD.TEXTIO.ALL;

ENTITY bus_tbw IS
END bus_tbw;

ARCHITECTURE testbench_arch OF bus_tbw IS
    COMPONENT bus_ctrl
        PORT (
            clock : In std_logic;
            reset : In std_logic;
            interrupt : In std_logic;
            adr_from_ei : In std_logic_vector (31 DownTo 0);
            instr_to_ei : Out std_logic_vector (31 DownTo 0);
            req_from_mem : In std_logic;
            r_w_from_mem : In std_logic;
            adr_from_mem : In std_logic_vector (31 DownTo 0);
            data_from_mem : In std_logic_vector (31 DownTo 0);
            data_to_mem : Out std_logic_vector (31 DownTo 0);
            load_to_video : Out std_logic;
            vsync_to_video : Out std_logic;
            hsync_to_video : Out std_logic;
            blank_to_video : Out std_logic;
            byte_to_video : Out std_logic_vector (7 DownTo 0);
            stop_all : In std_logic
        );
    END COMPONENT;

    SIGNAL clock : std_logic := '0';
    SIGNAL reset : std_logic := '1';
    SIGNAL interrupt : std_logic := '0';
    SIGNAL adr_from_ei : std_logic_vector (31 DownTo 0) := "00000000000000000000000000000000";
    SIGNAL instr_to_ei : std_logic_vector (31 DownTo 0) := "UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU";
    SIGNAL req_from_mem : std_logic := '0';
    SIGNAL r_w_from_mem : std_logic := '0';
    SIGNAL adr_from_mem : std_logic_vector (31 DownTo 0) := "00000000000000000000000000000000";
    SIGNAL data_from_mem : std_logic_vector (31 DownTo 0) := "00000000000000000000000000000000";
    SIGNAL data_to_mem : std_logic_vector (31 DownTo 0) := "UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU";
    SIGNAL load_to_video : std_logic := 'U';
    SIGNAL vsync_to_video : std_logic := 'U';
    SIGNAL hsync_to_video : std_logic := 'U';
    SIGNAL blank_to_video : std_logic := 'U';
    SIGNAL byte_to_video : std_logic_vector (7 DownTo 0) := "UUUUUUUU";
    SIGNAL stop_all : std_logic := '0';

    SHARED VARIABLE TX_ERROR : INTEGER := 0;
    SHARED VARIABLE TX_OUT : LINE;

    constant PERIOD : time := 200 ns;
    constant DUTY_CYCLE : real := 0.5;
    constant OFFSET : time := 0 ns;

    BEGIN
        UUT : bus_ctrl
        PORT MAP (
            clock => clock,
            reset => reset,
            interrupt => interrupt,
            adr_from_ei => adr_from_ei,
            instr_to_ei => instr_to_ei,
            req_from_mem => req_from_mem,
            r_w_from_mem => r_w_from_mem,
            adr_from_mem => adr_from_mem,
            data_from_mem => data_from_mem,
            data_to_mem => data_to_mem,
            load_to_video => load_to_video,
            vsync_to_video => vsync_to_video,
            hsync_to_video => hsync_to_video,
            blank_to_video => blank_to_video,
            byte_to_video => byte_to_video,
            stop_all => stop_all
        );

        PROCESS    -- clock process for clock
        BEGIN
            WAIT for OFFSET;
            CLOCK_LOOP : LOOP
                clock <= '0';
                WAIT FOR (PERIOD - (PERIOD * DUTY_CYCLE));
                clock <= '1';
                WAIT FOR (PERIOD * DUTY_CYCLE);
            END LOOP CLOCK_LOOP;
        END PROCESS;

        PROCESS
            PROCEDURE CHECK_blank_to_video(
                next_blank_to_video : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (blank_to_video /= next_blank_to_video) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns blank_to_video="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, blank_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_blank_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_byte_to_video(
                next_byte_to_video : std_logic_vector (7 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (byte_to_video /= next_byte_to_video) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns byte_to_video="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, byte_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_byte_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_data_to_mem(
                next_data_to_mem : std_logic_vector (31 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (data_to_mem /= next_data_to_mem) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns data_to_mem="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, data_to_mem);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_data_to_mem);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_hsync_to_video(
                next_hsync_to_video : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (hsync_to_video /= next_hsync_to_video) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns hsync_to_video="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, hsync_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_hsync_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_instr_to_ei(
                next_instr_to_ei : std_logic_vector (31 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (instr_to_ei /= next_instr_to_ei) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns instr_to_ei="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, instr_to_ei);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_instr_to_ei);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_load_to_video(
                next_load_to_video : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (load_to_video /= next_load_to_video) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns load_to_video="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, load_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_load_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_vsync_to_video(
                next_vsync_to_video : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (vsync_to_video /= next_vsync_to_video) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns vsync_to_video="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, vsync_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_vsync_to_video);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            BEGIN
                -- -------------  Current Time:  85ns
                WAIT FOR 85 ns;
                reset <= '0';
                req_from_mem <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  115ns
                WAIT FOR 30 ns;
                CHECK_load_to_video('0', 115);
                CHECK_vsync_to_video('0', 115);
                CHECK_hsync_to_video('0', 115);
                CHECK_blank_to_video('0', 115);
                CHECK_instr_to_ei("00100000000101000000000000011110", 115);
                CHECK_data_to_mem("00100000000101000000000000011110", 115);
                CHECK_byte_to_video("00000000", 115);
                -- -------------------------------------
                -- -------------  Current Time:  485ns
                WAIT FOR 370 ns;
                stop_all <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  1085ns
                WAIT FOR 600 ns;
                adr_from_mem <= "00000000000000000100000000000010";
                -- -------------------------------------
                -- -------------  Current Time:  1115ns
                WAIT FOR 30 ns;
                CHECK_data_to_mem("00000000000000000000000000000000", 1115);
                -- -------------------------------------
                -- -------------  Current Time:  3485ns
                WAIT FOR 2370 ns;
                req_from_mem <= '0';
                stop_all <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  3515ns
                WAIT FOR 30 ns;
                CHECK_hsync_to_video('1', 3515);
                -- -------------------------------------
                WAIT FOR 1685 ns;

                IF (TX_ERROR = 0) THEN
                    STD.TEXTIO.write(TX_OUT, string'("No errors or warnings"));
                    ASSERT (FALSE) REPORT
                      "Simulation successful (not a failure).  No problems detected."
                      SEVERITY FAILURE;
                ELSE
                    STD.TEXTIO.write(TX_OUT, TX_ERROR);
                    STD.TEXTIO.write(TX_OUT,
                        string'(" errors found in simulation"));
                    ASSERT (FALSE) REPORT "Errors found during simulation"
                         SEVERITY FAILURE;
                END IF;
            END PROCESS;

    END testbench_arch;



