
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
USE IEEE.STD_LOGIC_TEXTIO.ALL;
USE STD.TEXTIO.ALL;

ENTITY video_ctrl_tbw IS
END video_ctrl_tbw;

ARCHITECTURE testbench_arch OF video_ctrl_tbw IS
    FILE RESULTS: TEXT OPEN WRITE_MODE IS "results.txt";

    COMPONENT video_controller
        PORT (
            Pixel_Clock : In std_logic;
            Reset : In std_logic;
            RT_Font_Byte : In std_logic_vector (7 DownTo 0);
            RT_Shift_Load : In std_logic;
            RT_Blank : In std_logic;
            RT_Hsync : In std_logic;
            RT_VSync : In std_logic;
            VIDOUT_CLK : Out std_logic;
            VIDOUT_RED : Out std_logic_vector (9 DownTo 0);
            VIDOUT_GREEN : Out std_logic_vector (9 DownTo 0);
            VIDOUT_BLUE : Out std_logic_vector (9 DownTo 0);
            VIDOUT_BLANK_N : Out std_logic;
            VIDOUT_HSYNC_N : Out std_logic;
            VIDOUT_VSYNC_N : Out std_logic
        );
    END COMPONENT;

    SIGNAL Pixel_Clock : std_logic := '0';
    SIGNAL Reset : std_logic := '0';
    SIGNAL RT_Font_Byte : std_logic_vector (7 DownTo 0) := "00000000";
    SIGNAL RT_Shift_Load : std_logic := '0';
    SIGNAL RT_Blank : std_logic := '0';
    SIGNAL RT_Hsync : std_logic := '0';
    SIGNAL RT_VSync : std_logic := '0';
    SIGNAL VIDOUT_CLK : std_logic := '0';
    SIGNAL VIDOUT_RED : std_logic_vector (9 DownTo 0) := "0000000000";
    SIGNAL VIDOUT_GREEN : std_logic_vector (9 DownTo 0) := "0000000000";
    SIGNAL VIDOUT_BLUE : std_logic_vector (9 DownTo 0) := "0000000000";
    SIGNAL VIDOUT_BLANK_N : std_logic := '0';
    SIGNAL VIDOUT_HSYNC_N : std_logic := '0';
    SIGNAL VIDOUT_VSYNC_N : std_logic := '0';

    SHARED VARIABLE TX_ERROR : INTEGER := 0;
    SHARED VARIABLE TX_OUT : LINE;

    constant PERIOD : time := 200 ns;
    constant DUTY_CYCLE : real := 0.5;
    constant OFFSET : time := 0 ns;

    BEGIN
        UUT : video_controller
        PORT MAP (
            Pixel_Clock => Pixel_Clock,
            Reset => Reset,
            RT_Font_Byte => RT_Font_Byte,
            RT_Shift_Load => RT_Shift_Load,
            RT_Blank => RT_Blank,
            RT_Hsync => RT_Hsync,
            RT_VSync => RT_VSync,
            VIDOUT_CLK => VIDOUT_CLK,
            VIDOUT_RED => VIDOUT_RED,
            VIDOUT_GREEN => VIDOUT_GREEN,
            VIDOUT_BLUE => VIDOUT_BLUE,
            VIDOUT_BLANK_N => VIDOUT_BLANK_N,
            VIDOUT_HSYNC_N => VIDOUT_HSYNC_N,
            VIDOUT_VSYNC_N => VIDOUT_VSYNC_N
        );

        PROCESS    -- clock process for Pixel_Clock
        BEGIN
            WAIT for OFFSET;
            CLOCK_LOOP : LOOP
                Pixel_Clock <= '0';
                WAIT FOR (PERIOD - (PERIOD * DUTY_CYCLE));
                Pixel_Clock <= '1';
                WAIT FOR (PERIOD * DUTY_CYCLE);
            END LOOP CLOCK_LOOP;
        END PROCESS;

        PROCESS
            PROCEDURE CHECK_VIDOUT_BLANK_N(
                next_VIDOUT_BLANK_N : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_BLANK_N /= next_VIDOUT_BLANK_N) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_BLANK_N="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_BLANK_N);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_BLANK_N);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_BLUE(
                next_VIDOUT_BLUE : std_logic_vector (9 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_BLUE /= next_VIDOUT_BLUE) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_BLUE="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_BLUE);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_BLUE);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_CLK(
                next_VIDOUT_CLK : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_CLK /= next_VIDOUT_CLK) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_CLK="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_CLK);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_CLK);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_GREEN(
                next_VIDOUT_GREEN : std_logic_vector (9 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_GREEN /= next_VIDOUT_GREEN) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_GREEN="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_GREEN);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_GREEN);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_HSYNC_N(
                next_VIDOUT_HSYNC_N : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_HSYNC_N /= next_VIDOUT_HSYNC_N) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_HSYNC_N="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_HSYNC_N);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_HSYNC_N);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_RED(
                next_VIDOUT_RED : std_logic_vector (9 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_RED /= next_VIDOUT_RED) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_RED="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_RED);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_RED);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_VIDOUT_VSYNC_N(
                next_VIDOUT_VSYNC_N : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (VIDOUT_VSYNC_N /= next_VIDOUT_VSYNC_N) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns VIDOUT_VSYNC_N="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, VIDOUT_VSYNC_N);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_VIDOUT_VSYNC_N);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.writeline(RESULTS, TX_LOC);
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            BEGIN
                -- -------------  Current Time:  85ns
                WAIT FOR 85 ns;
                Reset <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  115ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_CLK('1', 115);
                CHECK_VIDOUT_BLUE("0000000000", 115);
                CHECK_VIDOUT_GREEN("0000000000", 115);
                CHECK_VIDOUT_RED("0000000000", 115);
                -- -------------------------------------
                -- -------------  Current Time:  285ns
                WAIT FOR 170 ns;
                RT_Blank <= '1';
                RT_Hsync <= '1';
                Reset <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  315ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLANK_N('0', 315);
                CHECK_VIDOUT_HSYNC_N('0', 315);
                CHECK_VIDOUT_BLUE("1111111111", 315);
                CHECK_VIDOUT_GREEN("1111111111", 315);
                CHECK_VIDOUT_RED("1111111111", 315);
                -- -------------------------------------
                -- -------------  Current Time:  485ns
                WAIT FOR 170 ns;
                RT_Blank <= '0';
                RT_Hsync <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  515ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("0000000000", 515);
                CHECK_VIDOUT_GREEN("0000000000", 515);
                CHECK_VIDOUT_RED("0000000000", 515);
                -- -------------------------------------
                -- -------------  Current Time:  715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 715);
                CHECK_VIDOUT_GREEN("1111111111", 715);
                CHECK_VIDOUT_RED("1111111111", 715);
                -- -------------------------------------
                -- -------------  Current Time:  915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 915);
                CHECK_VIDOUT_GREEN("0000000000", 915);
                CHECK_VIDOUT_RED("0000000000", 915);
                -- -------------------------------------
                -- -------------  Current Time:  1115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 1115);
                CHECK_VIDOUT_GREEN("1111111111", 1115);
                CHECK_VIDOUT_RED("1111111111", 1115);
                -- -------------------------------------
                -- -------------  Current Time:  1315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 1315);
                CHECK_VIDOUT_GREEN("0000000000", 1315);
                CHECK_VIDOUT_RED("0000000000", 1315);
                -- -------------------------------------
                -- -------------  Current Time:  1515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 1515);
                CHECK_VIDOUT_GREEN("1111111111", 1515);
                CHECK_VIDOUT_RED("1111111111", 1515);
                -- -------------------------------------
                -- -------------  Current Time:  1685ns
                WAIT FOR 170 ns;
                RT_Blank <= '1';
                RT_Hsync <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  1715ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLANK_N('1', 1715);
                CHECK_VIDOUT_HSYNC_N('1', 1715);
                -- -------------------------------------
                -- -------------  Current Time:  1885ns
                WAIT FOR 170 ns;
                RT_Blank <= '0';
                RT_Hsync <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  2115ns
                WAIT FOR 230 ns;
                CHECK_VIDOUT_BLUE("0000000000", 2115);
                CHECK_VIDOUT_GREEN("0000000000", 2115);
                CHECK_VIDOUT_RED("0000000000", 2115);
                -- -------------------------------------
                -- -------------  Current Time:  2315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 2315);
                CHECK_VIDOUT_GREEN("1111111111", 2315);
                CHECK_VIDOUT_RED("1111111111", 2315);
                -- -------------------------------------
                -- -------------  Current Time:  2515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 2515);
                CHECK_VIDOUT_GREEN("0000000000", 2515);
                CHECK_VIDOUT_RED("0000000000", 2515);
                -- -------------------------------------
                -- -------------  Current Time:  2685ns
                WAIT FOR 170 ns;
                RT_Font_Byte <= "11010011";
                -- -------------------------------------
                -- -------------  Current Time:  2715ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("1111111111", 2715);
                CHECK_VIDOUT_GREEN("1111111111", 2715);
                CHECK_VIDOUT_RED("1111111111", 2715);
                -- -------------------------------------
                -- -------------  Current Time:  2885ns
                WAIT FOR 170 ns;
                RT_Shift_Load <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  2915ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("0000000000", 2915);
                CHECK_VIDOUT_GREEN("0000000000", 2915);
                CHECK_VIDOUT_RED("0000000000", 2915);
                -- -------------------------------------
                -- -------------  Current Time:  3085ns
                WAIT FOR 170 ns;
                RT_Blank <= '1';
                RT_Shift_Load <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  3115ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLANK_N('0', 3115);
                CHECK_VIDOUT_BLUE("1111111111", 3115);
                CHECK_VIDOUT_GREEN("1111111111", 3115);
                CHECK_VIDOUT_RED("1111111111", 3115);
                -- -------------------------------------
                -- -------------  Current Time:  3285ns
                WAIT FOR 170 ns;
                RT_Blank <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  3515ns
                WAIT FOR 230 ns;
                CHECK_VIDOUT_BLUE("0000000000", 3515);
                CHECK_VIDOUT_GREEN("0000000000", 3515);
                CHECK_VIDOUT_RED("0000000000", 3515);
                -- -------------------------------------
                -- -------------  Current Time:  3715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 3715);
                CHECK_VIDOUT_GREEN("1111111111", 3715);
                CHECK_VIDOUT_RED("1111111111", 3715);
                -- -------------------------------------
                -- -------------  Current Time:  3915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 3915);
                CHECK_VIDOUT_GREEN("0000000000", 3915);
                CHECK_VIDOUT_RED("0000000000", 3915);
                -- -------------------------------------
                -- -------------  Current Time:  4085ns
                WAIT FOR 170 ns;
                RT_Font_Byte <= "01110000";
                -- -------------------------------------
                -- -------------  Current Time:  4315ns
                WAIT FOR 230 ns;
                CHECK_VIDOUT_BLUE("1111111111", 4315);
                CHECK_VIDOUT_GREEN("1111111111", 4315);
                CHECK_VIDOUT_RED("1111111111", 4315);
                -- -------------------------------------
                -- -------------  Current Time:  4485ns
                WAIT FOR 170 ns;
                RT_Shift_Load <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  4685ns
                WAIT FOR 200 ns;
                RT_Shift_Load <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  4715ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("0000000000", 4715);
                CHECK_VIDOUT_GREEN("0000000000", 4715);
                CHECK_VIDOUT_RED("0000000000", 4715);
                -- -------------------------------------
                -- -------------  Current Time:  4915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("1111111111", 4915);
                CHECK_VIDOUT_GREEN("1111111111", 4915);
                CHECK_VIDOUT_RED("1111111111", 4915);
                -- -------------------------------------
                -- -------------  Current Time:  5515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 5515);
                CHECK_VIDOUT_GREEN("0000000000", 5515);
                CHECK_VIDOUT_RED("0000000000", 5515);
                -- -------------------------------------
                -- -------------  Current Time:  6285ns
                WAIT FOR 770 ns;
                RT_Shift_Load <= '1';
                RT_Font_Byte <= "00111001";
                -- -------------------------------------
                -- -------------  Current Time:  6485ns
                WAIT FOR 200 ns;
                RT_Shift_Load <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  6915ns
                WAIT FOR 430 ns;
                CHECK_VIDOUT_BLUE("1111111111", 6915);
                CHECK_VIDOUT_GREEN("1111111111", 6915);
                CHECK_VIDOUT_RED("1111111111", 6915);
                -- -------------------------------------
                -- -------------  Current Time:  7515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 7515);
                CHECK_VIDOUT_GREEN("0000000000", 7515);
                CHECK_VIDOUT_RED("0000000000", 7515);
                -- -------------------------------------
                -- -------------  Current Time:  7915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 7915);
                CHECK_VIDOUT_GREEN("1111111111", 7915);
                CHECK_VIDOUT_RED("1111111111", 7915);
                -- -------------------------------------
                -- -------------  Current Time:  8115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 8115);
                CHECK_VIDOUT_GREEN("0000000000", 8115);
                CHECK_VIDOUT_RED("0000000000", 8115);
                -- -------------------------------------
                -- -------------  Current Time:  8285ns
                WAIT FOR 170 ns;
                RT_Blank <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  8485ns
                WAIT FOR 200 ns;
                RT_Blank <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  8515ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("1111111111", 8515);
                CHECK_VIDOUT_GREEN("1111111111", 8515);
                CHECK_VIDOUT_RED("1111111111", 8515);
                -- -------------------------------------
                -- -------------  Current Time:  9115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 9115);
                CHECK_VIDOUT_GREEN("0000000000", 9115);
                CHECK_VIDOUT_RED("0000000000", 9115);
                -- -------------------------------------
                -- -------------  Current Time:  9515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 9515);
                CHECK_VIDOUT_GREEN("1111111111", 9515);
                CHECK_VIDOUT_RED("1111111111", 9515);
                -- -------------------------------------
                -- -------------  Current Time:  9715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 9715);
                CHECK_VIDOUT_GREEN("0000000000", 9715);
                CHECK_VIDOUT_RED("0000000000", 9715);
                -- -------------------------------------
                -- -------------  Current Time:  10115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 10115);
                CHECK_VIDOUT_GREEN("1111111111", 10115);
                CHECK_VIDOUT_RED("1111111111", 10115);
                -- -------------------------------------
                -- -------------  Current Time:  10315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_HSYNC_N('0', 10315);
                -- -------------------------------------
                -- -------------  Current Time:  10715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("0000000000", 10715);
                CHECK_VIDOUT_GREEN("0000000000", 10715);
                CHECK_VIDOUT_RED("0000000000", 10715);
                -- -------------------------------------
                -- -------------  Current Time:  11115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 11115);
                CHECK_VIDOUT_GREEN("1111111111", 11115);
                CHECK_VIDOUT_RED("1111111111", 11115);
                -- -------------------------------------
                -- -------------  Current Time:  11315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 11315);
                CHECK_VIDOUT_GREEN("0000000000", 11315);
                CHECK_VIDOUT_RED("0000000000", 11315);
                -- -------------------------------------
                -- -------------  Current Time:  11485ns
                WAIT FOR 170 ns;
                RT_Hsync <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  11685ns
                WAIT FOR 200 ns;
                RT_Hsync <= '0';
                -- -------------------------------------
                -- -------------  Current Time:  11715ns
                WAIT FOR 30 ns;
                CHECK_VIDOUT_BLUE("1111111111", 11715);
                CHECK_VIDOUT_GREEN("1111111111", 11715);
                CHECK_VIDOUT_RED("1111111111", 11715);
                -- -------------------------------------
                -- -------------  Current Time:  12315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 12315);
                CHECK_VIDOUT_GREEN("0000000000", 12315);
                CHECK_VIDOUT_RED("0000000000", 12315);
                -- -------------------------------------
                -- -------------  Current Time:  12715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 12715);
                CHECK_VIDOUT_GREEN("1111111111", 12715);
                CHECK_VIDOUT_RED("1111111111", 12715);
                -- -------------------------------------
                -- -------------  Current Time:  12915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 12915);
                CHECK_VIDOUT_GREEN("0000000000", 12915);
                CHECK_VIDOUT_RED("0000000000", 12915);
                -- -------------------------------------
                -- -------------  Current Time:  13315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 13315);
                CHECK_VIDOUT_GREEN("1111111111", 13315);
                CHECK_VIDOUT_RED("1111111111", 13315);
                -- -------------------------------------
                -- -------------  Current Time:  13915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 13915);
                CHECK_VIDOUT_GREEN("0000000000", 13915);
                CHECK_VIDOUT_RED("0000000000", 13915);
                -- -------------------------------------
                -- -------------  Current Time:  14315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 14315);
                CHECK_VIDOUT_GREEN("1111111111", 14315);
                CHECK_VIDOUT_RED("1111111111", 14315);
                -- -------------------------------------
                -- -------------  Current Time:  14515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 14515);
                CHECK_VIDOUT_GREEN("0000000000", 14515);
                CHECK_VIDOUT_RED("0000000000", 14515);
                -- -------------------------------------
                -- -------------  Current Time:  14915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 14915);
                CHECK_VIDOUT_GREEN("1111111111", 14915);
                CHECK_VIDOUT_RED("1111111111", 14915);
                -- -------------------------------------
                -- -------------  Current Time:  15515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 15515);
                CHECK_VIDOUT_GREEN("0000000000", 15515);
                CHECK_VIDOUT_RED("0000000000", 15515);
                -- -------------------------------------
                -- -------------  Current Time:  15915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 15915);
                CHECK_VIDOUT_GREEN("1111111111", 15915);
                CHECK_VIDOUT_RED("1111111111", 15915);
                -- -------------------------------------
                -- -------------  Current Time:  16115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 16115);
                CHECK_VIDOUT_GREEN("0000000000", 16115);
                CHECK_VIDOUT_RED("0000000000", 16115);
                -- -------------------------------------
                -- -------------  Current Time:  16515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 16515);
                CHECK_VIDOUT_GREEN("1111111111", 16515);
                CHECK_VIDOUT_RED("1111111111", 16515);
                -- -------------------------------------
                -- -------------  Current Time:  17115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 17115);
                CHECK_VIDOUT_GREEN("0000000000", 17115);
                CHECK_VIDOUT_RED("0000000000", 17115);
                -- -------------------------------------
                -- -------------  Current Time:  17515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 17515);
                CHECK_VIDOUT_GREEN("1111111111", 17515);
                CHECK_VIDOUT_RED("1111111111", 17515);
                -- -------------------------------------
                -- -------------  Current Time:  17715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 17715);
                CHECK_VIDOUT_GREEN("0000000000", 17715);
                CHECK_VIDOUT_RED("0000000000", 17715);
                -- -------------------------------------
                -- -------------  Current Time:  18115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 18115);
                CHECK_VIDOUT_GREEN("1111111111", 18115);
                CHECK_VIDOUT_RED("1111111111", 18115);
                -- -------------------------------------
                -- -------------  Current Time:  18715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 18715);
                CHECK_VIDOUT_GREEN("0000000000", 18715);
                CHECK_VIDOUT_RED("0000000000", 18715);
                -- -------------------------------------
                -- -------------  Current Time:  19115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 19115);
                CHECK_VIDOUT_GREEN("1111111111", 19115);
                CHECK_VIDOUT_RED("1111111111", 19115);
                -- -------------------------------------
                -- -------------  Current Time:  19315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 19315);
                CHECK_VIDOUT_GREEN("0000000000", 19315);
                CHECK_VIDOUT_RED("0000000000", 19315);
                -- -------------------------------------
                -- -------------  Current Time:  19715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 19715);
                CHECK_VIDOUT_GREEN("1111111111", 19715);
                CHECK_VIDOUT_RED("1111111111", 19715);
                -- -------------------------------------
                -- -------------  Current Time:  20315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 20315);
                CHECK_VIDOUT_GREEN("0000000000", 20315);
                CHECK_VIDOUT_RED("0000000000", 20315);
                -- -------------------------------------
                -- -------------  Current Time:  20715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 20715);
                CHECK_VIDOUT_GREEN("1111111111", 20715);
                CHECK_VIDOUT_RED("1111111111", 20715);
                -- -------------------------------------
                -- -------------  Current Time:  20915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 20915);
                CHECK_VIDOUT_GREEN("0000000000", 20915);
                CHECK_VIDOUT_RED("0000000000", 20915);
                -- -------------------------------------
                -- -------------  Current Time:  21315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 21315);
                CHECK_VIDOUT_GREEN("1111111111", 21315);
                CHECK_VIDOUT_RED("1111111111", 21315);
                -- -------------------------------------
                -- -------------  Current Time:  21915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 21915);
                CHECK_VIDOUT_GREEN("0000000000", 21915);
                CHECK_VIDOUT_RED("0000000000", 21915);
                -- -------------------------------------
                -- -------------  Current Time:  22315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 22315);
                CHECK_VIDOUT_GREEN("1111111111", 22315);
                CHECK_VIDOUT_RED("1111111111", 22315);
                -- -------------------------------------
                -- -------------  Current Time:  22515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 22515);
                CHECK_VIDOUT_GREEN("0000000000", 22515);
                CHECK_VIDOUT_RED("0000000000", 22515);
                -- -------------------------------------
                -- -------------  Current Time:  22915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 22915);
                CHECK_VIDOUT_GREEN("1111111111", 22915);
                CHECK_VIDOUT_RED("1111111111", 22915);
                -- -------------------------------------
                -- -------------  Current Time:  23515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 23515);
                CHECK_VIDOUT_GREEN("0000000000", 23515);
                CHECK_VIDOUT_RED("0000000000", 23515);
                -- -------------------------------------
                -- -------------  Current Time:  23915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 23915);
                CHECK_VIDOUT_GREEN("1111111111", 23915);
                CHECK_VIDOUT_RED("1111111111", 23915);
                -- -------------------------------------
                -- -------------  Current Time:  24115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 24115);
                CHECK_VIDOUT_GREEN("0000000000", 24115);
                CHECK_VIDOUT_RED("0000000000", 24115);
                -- -------------------------------------
                -- -------------  Current Time:  24515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 24515);
                CHECK_VIDOUT_GREEN("1111111111", 24515);
                CHECK_VIDOUT_RED("1111111111", 24515);
                -- -------------------------------------
                -- -------------  Current Time:  25115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 25115);
                CHECK_VIDOUT_GREEN("0000000000", 25115);
                CHECK_VIDOUT_RED("0000000000", 25115);
                -- -------------------------------------
                -- -------------  Current Time:  25515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 25515);
                CHECK_VIDOUT_GREEN("1111111111", 25515);
                CHECK_VIDOUT_RED("1111111111", 25515);
                -- -------------------------------------
                -- -------------  Current Time:  25715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 25715);
                CHECK_VIDOUT_GREEN("0000000000", 25715);
                CHECK_VIDOUT_RED("0000000000", 25715);
                -- -------------------------------------
                -- -------------  Current Time:  26115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 26115);
                CHECK_VIDOUT_GREEN("1111111111", 26115);
                CHECK_VIDOUT_RED("1111111111", 26115);
                -- -------------------------------------
                -- -------------  Current Time:  26715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 26715);
                CHECK_VIDOUT_GREEN("0000000000", 26715);
                CHECK_VIDOUT_RED("0000000000", 26715);
                -- -------------------------------------
                -- -------------  Current Time:  27115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 27115);
                CHECK_VIDOUT_GREEN("1111111111", 27115);
                CHECK_VIDOUT_RED("1111111111", 27115);
                -- -------------------------------------
                -- -------------  Current Time:  27315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 27315);
                CHECK_VIDOUT_GREEN("0000000000", 27315);
                CHECK_VIDOUT_RED("0000000000", 27315);
                -- -------------------------------------
                -- -------------  Current Time:  27715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 27715);
                CHECK_VIDOUT_GREEN("1111111111", 27715);
                CHECK_VIDOUT_RED("1111111111", 27715);
                -- -------------------------------------
                -- -------------  Current Time:  28315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 28315);
                CHECK_VIDOUT_GREEN("0000000000", 28315);
                CHECK_VIDOUT_RED("0000000000", 28315);
                -- -------------------------------------
                -- -------------  Current Time:  28715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 28715);
                CHECK_VIDOUT_GREEN("1111111111", 28715);
                CHECK_VIDOUT_RED("1111111111", 28715);
                -- -------------------------------------
                -- -------------  Current Time:  28915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 28915);
                CHECK_VIDOUT_GREEN("0000000000", 28915);
                CHECK_VIDOUT_RED("0000000000", 28915);
                -- -------------------------------------
                -- -------------  Current Time:  29315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 29315);
                CHECK_VIDOUT_GREEN("1111111111", 29315);
                CHECK_VIDOUT_RED("1111111111", 29315);
                -- -------------------------------------
                -- -------------  Current Time:  29915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 29915);
                CHECK_VIDOUT_GREEN("0000000000", 29915);
                CHECK_VIDOUT_RED("0000000000", 29915);
                -- -------------------------------------
                -- -------------  Current Time:  30315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 30315);
                CHECK_VIDOUT_GREEN("1111111111", 30315);
                CHECK_VIDOUT_RED("1111111111", 30315);
                -- -------------------------------------
                -- -------------  Current Time:  30515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 30515);
                CHECK_VIDOUT_GREEN("0000000000", 30515);
                CHECK_VIDOUT_RED("0000000000", 30515);
                -- -------------------------------------
                -- -------------  Current Time:  30915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 30915);
                CHECK_VIDOUT_GREEN("1111111111", 30915);
                CHECK_VIDOUT_RED("1111111111", 30915);
                -- -------------------------------------
                -- -------------  Current Time:  31515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 31515);
                CHECK_VIDOUT_GREEN("0000000000", 31515);
                CHECK_VIDOUT_RED("0000000000", 31515);
                -- -------------------------------------
                -- -------------  Current Time:  31915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 31915);
                CHECK_VIDOUT_GREEN("1111111111", 31915);
                CHECK_VIDOUT_RED("1111111111", 31915);
                -- -------------------------------------
                -- -------------  Current Time:  32115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 32115);
                CHECK_VIDOUT_GREEN("0000000000", 32115);
                CHECK_VIDOUT_RED("0000000000", 32115);
                -- -------------------------------------
                -- -------------  Current Time:  32515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 32515);
                CHECK_VIDOUT_GREEN("1111111111", 32515);
                CHECK_VIDOUT_RED("1111111111", 32515);
                -- -------------------------------------
                -- -------------  Current Time:  33115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 33115);
                CHECK_VIDOUT_GREEN("0000000000", 33115);
                CHECK_VIDOUT_RED("0000000000", 33115);
                -- -------------------------------------
                -- -------------  Current Time:  33515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 33515);
                CHECK_VIDOUT_GREEN("1111111111", 33515);
                CHECK_VIDOUT_RED("1111111111", 33515);
                -- -------------------------------------
                -- -------------  Current Time:  33715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 33715);
                CHECK_VIDOUT_GREEN("0000000000", 33715);
                CHECK_VIDOUT_RED("0000000000", 33715);
                -- -------------------------------------
                -- -------------  Current Time:  34115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 34115);
                CHECK_VIDOUT_GREEN("1111111111", 34115);
                CHECK_VIDOUT_RED("1111111111", 34115);
                -- -------------------------------------
                -- -------------  Current Time:  34715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 34715);
                CHECK_VIDOUT_GREEN("0000000000", 34715);
                CHECK_VIDOUT_RED("0000000000", 34715);
                -- -------------------------------------
                -- -------------  Current Time:  35115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 35115);
                CHECK_VIDOUT_GREEN("1111111111", 35115);
                CHECK_VIDOUT_RED("1111111111", 35115);
                -- -------------------------------------
                -- -------------  Current Time:  35315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 35315);
                CHECK_VIDOUT_GREEN("0000000000", 35315);
                CHECK_VIDOUT_RED("0000000000", 35315);
                -- -------------------------------------
                -- -------------  Current Time:  35715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 35715);
                CHECK_VIDOUT_GREEN("1111111111", 35715);
                CHECK_VIDOUT_RED("1111111111", 35715);
                -- -------------------------------------
                -- -------------  Current Time:  36315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 36315);
                CHECK_VIDOUT_GREEN("0000000000", 36315);
                CHECK_VIDOUT_RED("0000000000", 36315);
                -- -------------------------------------
                -- -------------  Current Time:  36715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 36715);
                CHECK_VIDOUT_GREEN("1111111111", 36715);
                CHECK_VIDOUT_RED("1111111111", 36715);
                -- -------------------------------------
                -- -------------  Current Time:  36915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 36915);
                CHECK_VIDOUT_GREEN("0000000000", 36915);
                CHECK_VIDOUT_RED("0000000000", 36915);
                -- -------------------------------------
                -- -------------  Current Time:  37315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 37315);
                CHECK_VIDOUT_GREEN("1111111111", 37315);
                CHECK_VIDOUT_RED("1111111111", 37315);
                -- -------------------------------------
                -- -------------  Current Time:  37915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 37915);
                CHECK_VIDOUT_GREEN("0000000000", 37915);
                CHECK_VIDOUT_RED("0000000000", 37915);
                -- -------------------------------------
                -- -------------  Current Time:  38315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 38315);
                CHECK_VIDOUT_GREEN("1111111111", 38315);
                CHECK_VIDOUT_RED("1111111111", 38315);
                -- -------------------------------------
                -- -------------  Current Time:  38515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 38515);
                CHECK_VIDOUT_GREEN("0000000000", 38515);
                CHECK_VIDOUT_RED("0000000000", 38515);
                -- -------------------------------------
                -- -------------  Current Time:  38915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 38915);
                CHECK_VIDOUT_GREEN("1111111111", 38915);
                CHECK_VIDOUT_RED("1111111111", 38915);
                -- -------------------------------------
                -- -------------  Current Time:  39515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 39515);
                CHECK_VIDOUT_GREEN("0000000000", 39515);
                CHECK_VIDOUT_RED("0000000000", 39515);
                -- -------------------------------------
                -- -------------  Current Time:  39915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 39915);
                CHECK_VIDOUT_GREEN("1111111111", 39915);
                CHECK_VIDOUT_RED("1111111111", 39915);
                -- -------------------------------------
                -- -------------  Current Time:  40115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 40115);
                CHECK_VIDOUT_GREEN("0000000000", 40115);
                CHECK_VIDOUT_RED("0000000000", 40115);
                -- -------------------------------------
                -- -------------  Current Time:  40515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 40515);
                CHECK_VIDOUT_GREEN("1111111111", 40515);
                CHECK_VIDOUT_RED("1111111111", 40515);
                -- -------------------------------------
                -- -------------  Current Time:  41115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 41115);
                CHECK_VIDOUT_GREEN("0000000000", 41115);
                CHECK_VIDOUT_RED("0000000000", 41115);
                -- -------------------------------------
                -- -------------  Current Time:  41515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 41515);
                CHECK_VIDOUT_GREEN("1111111111", 41515);
                CHECK_VIDOUT_RED("1111111111", 41515);
                -- -------------------------------------
                -- -------------  Current Time:  41715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 41715);
                CHECK_VIDOUT_GREEN("0000000000", 41715);
                CHECK_VIDOUT_RED("0000000000", 41715);
                -- -------------------------------------
                -- -------------  Current Time:  42115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 42115);
                CHECK_VIDOUT_GREEN("1111111111", 42115);
                CHECK_VIDOUT_RED("1111111111", 42115);
                -- -------------------------------------
                -- -------------  Current Time:  42715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 42715);
                CHECK_VIDOUT_GREEN("0000000000", 42715);
                CHECK_VIDOUT_RED("0000000000", 42715);
                -- -------------------------------------
                -- -------------  Current Time:  43115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 43115);
                CHECK_VIDOUT_GREEN("1111111111", 43115);
                CHECK_VIDOUT_RED("1111111111", 43115);
                -- -------------------------------------
                -- -------------  Current Time:  43315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 43315);
                CHECK_VIDOUT_GREEN("0000000000", 43315);
                CHECK_VIDOUT_RED("0000000000", 43315);
                -- -------------------------------------
                -- -------------  Current Time:  43715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 43715);
                CHECK_VIDOUT_GREEN("1111111111", 43715);
                CHECK_VIDOUT_RED("1111111111", 43715);
                -- -------------------------------------
                -- -------------  Current Time:  44315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 44315);
                CHECK_VIDOUT_GREEN("0000000000", 44315);
                CHECK_VIDOUT_RED("0000000000", 44315);
                -- -------------------------------------
                -- -------------  Current Time:  44715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 44715);
                CHECK_VIDOUT_GREEN("1111111111", 44715);
                CHECK_VIDOUT_RED("1111111111", 44715);
                -- -------------------------------------
                -- -------------  Current Time:  44915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 44915);
                CHECK_VIDOUT_GREEN("0000000000", 44915);
                CHECK_VIDOUT_RED("0000000000", 44915);
                -- -------------------------------------
                -- -------------  Current Time:  45315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 45315);
                CHECK_VIDOUT_GREEN("1111111111", 45315);
                CHECK_VIDOUT_RED("1111111111", 45315);
                -- -------------------------------------
                -- -------------  Current Time:  45915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 45915);
                CHECK_VIDOUT_GREEN("0000000000", 45915);
                CHECK_VIDOUT_RED("0000000000", 45915);
                -- -------------------------------------
                -- -------------  Current Time:  46315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 46315);
                CHECK_VIDOUT_GREEN("1111111111", 46315);
                CHECK_VIDOUT_RED("1111111111", 46315);
                -- -------------------------------------
                -- -------------  Current Time:  46515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 46515);
                CHECK_VIDOUT_GREEN("0000000000", 46515);
                CHECK_VIDOUT_RED("0000000000", 46515);
                -- -------------------------------------
                -- -------------  Current Time:  46915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 46915);
                CHECK_VIDOUT_GREEN("1111111111", 46915);
                CHECK_VIDOUT_RED("1111111111", 46915);
                -- -------------------------------------
                -- -------------  Current Time:  47515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 47515);
                CHECK_VIDOUT_GREEN("0000000000", 47515);
                CHECK_VIDOUT_RED("0000000000", 47515);
                -- -------------------------------------
                -- -------------  Current Time:  47915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 47915);
                CHECK_VIDOUT_GREEN("1111111111", 47915);
                CHECK_VIDOUT_RED("1111111111", 47915);
                -- -------------------------------------
                -- -------------  Current Time:  48115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 48115);
                CHECK_VIDOUT_GREEN("0000000000", 48115);
                CHECK_VIDOUT_RED("0000000000", 48115);
                -- -------------------------------------
                -- -------------  Current Time:  48515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 48515);
                CHECK_VIDOUT_GREEN("1111111111", 48515);
                CHECK_VIDOUT_RED("1111111111", 48515);
                -- -------------------------------------
                -- -------------  Current Time:  49115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 49115);
                CHECK_VIDOUT_GREEN("0000000000", 49115);
                CHECK_VIDOUT_RED("0000000000", 49115);
                -- -------------------------------------
                -- -------------  Current Time:  49515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 49515);
                CHECK_VIDOUT_GREEN("1111111111", 49515);
                CHECK_VIDOUT_RED("1111111111", 49515);
                -- -------------------------------------
                -- -------------  Current Time:  49715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 49715);
                CHECK_VIDOUT_GREEN("0000000000", 49715);
                CHECK_VIDOUT_RED("0000000000", 49715);
                -- -------------------------------------
                -- -------------  Current Time:  50115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 50115);
                CHECK_VIDOUT_GREEN("1111111111", 50115);
                CHECK_VIDOUT_RED("1111111111", 50115);
                -- -------------------------------------
                -- -------------  Current Time:  50715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 50715);
                CHECK_VIDOUT_GREEN("0000000000", 50715);
                CHECK_VIDOUT_RED("0000000000", 50715);
                -- -------------------------------------
                -- -------------  Current Time:  51115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 51115);
                CHECK_VIDOUT_GREEN("1111111111", 51115);
                CHECK_VIDOUT_RED("1111111111", 51115);
                -- -------------------------------------
                -- -------------  Current Time:  51315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 51315);
                CHECK_VIDOUT_GREEN("0000000000", 51315);
                CHECK_VIDOUT_RED("0000000000", 51315);
                -- -------------------------------------
                -- -------------  Current Time:  51715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 51715);
                CHECK_VIDOUT_GREEN("1111111111", 51715);
                CHECK_VIDOUT_RED("1111111111", 51715);
                -- -------------------------------------
                -- -------------  Current Time:  52315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 52315);
                CHECK_VIDOUT_GREEN("0000000000", 52315);
                CHECK_VIDOUT_RED("0000000000", 52315);
                -- -------------------------------------
                -- -------------  Current Time:  52715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 52715);
                CHECK_VIDOUT_GREEN("1111111111", 52715);
                CHECK_VIDOUT_RED("1111111111", 52715);
                -- -------------------------------------
                -- -------------  Current Time:  52915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 52915);
                CHECK_VIDOUT_GREEN("0000000000", 52915);
                CHECK_VIDOUT_RED("0000000000", 52915);
                -- -------------------------------------
                -- -------------  Current Time:  53315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 53315);
                CHECK_VIDOUT_GREEN("1111111111", 53315);
                CHECK_VIDOUT_RED("1111111111", 53315);
                -- -------------------------------------
                -- -------------  Current Time:  53915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 53915);
                CHECK_VIDOUT_GREEN("0000000000", 53915);
                CHECK_VIDOUT_RED("0000000000", 53915);
                -- -------------------------------------
                -- -------------  Current Time:  54315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 54315);
                CHECK_VIDOUT_GREEN("1111111111", 54315);
                CHECK_VIDOUT_RED("1111111111", 54315);
                -- -------------------------------------
                -- -------------  Current Time:  54515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 54515);
                CHECK_VIDOUT_GREEN("0000000000", 54515);
                CHECK_VIDOUT_RED("0000000000", 54515);
                -- -------------------------------------
                -- -------------  Current Time:  54915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 54915);
                CHECK_VIDOUT_GREEN("1111111111", 54915);
                CHECK_VIDOUT_RED("1111111111", 54915);
                -- -------------------------------------
                -- -------------  Current Time:  55515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 55515);
                CHECK_VIDOUT_GREEN("0000000000", 55515);
                CHECK_VIDOUT_RED("0000000000", 55515);
                -- -------------------------------------
                -- -------------  Current Time:  55915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 55915);
                CHECK_VIDOUT_GREEN("1111111111", 55915);
                CHECK_VIDOUT_RED("1111111111", 55915);
                -- -------------------------------------
                -- -------------  Current Time:  56115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 56115);
                CHECK_VIDOUT_GREEN("0000000000", 56115);
                CHECK_VIDOUT_RED("0000000000", 56115);
                -- -------------------------------------
                -- -------------  Current Time:  56515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 56515);
                CHECK_VIDOUT_GREEN("1111111111", 56515);
                CHECK_VIDOUT_RED("1111111111", 56515);
                -- -------------------------------------
                -- -------------  Current Time:  57115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 57115);
                CHECK_VIDOUT_GREEN("0000000000", 57115);
                CHECK_VIDOUT_RED("0000000000", 57115);
                -- -------------------------------------
                -- -------------  Current Time:  57515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 57515);
                CHECK_VIDOUT_GREEN("1111111111", 57515);
                CHECK_VIDOUT_RED("1111111111", 57515);
                -- -------------------------------------
                -- -------------  Current Time:  57715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 57715);
                CHECK_VIDOUT_GREEN("0000000000", 57715);
                CHECK_VIDOUT_RED("0000000000", 57715);
                -- -------------------------------------
                -- -------------  Current Time:  58115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 58115);
                CHECK_VIDOUT_GREEN("1111111111", 58115);
                CHECK_VIDOUT_RED("1111111111", 58115);
                -- -------------------------------------
                -- -------------  Current Time:  58715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 58715);
                CHECK_VIDOUT_GREEN("0000000000", 58715);
                CHECK_VIDOUT_RED("0000000000", 58715);
                -- -------------------------------------
                -- -------------  Current Time:  59115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 59115);
                CHECK_VIDOUT_GREEN("1111111111", 59115);
                CHECK_VIDOUT_RED("1111111111", 59115);
                -- -------------------------------------
                -- -------------  Current Time:  59315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 59315);
                CHECK_VIDOUT_GREEN("0000000000", 59315);
                CHECK_VIDOUT_RED("0000000000", 59315);
                -- -------------------------------------
                -- -------------  Current Time:  59715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 59715);
                CHECK_VIDOUT_GREEN("1111111111", 59715);
                CHECK_VIDOUT_RED("1111111111", 59715);
                -- -------------------------------------
                -- -------------  Current Time:  60315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 60315);
                CHECK_VIDOUT_GREEN("0000000000", 60315);
                CHECK_VIDOUT_RED("0000000000", 60315);
                -- -------------------------------------
                -- -------------  Current Time:  60715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 60715);
                CHECK_VIDOUT_GREEN("1111111111", 60715);
                CHECK_VIDOUT_RED("1111111111", 60715);
                -- -------------------------------------
                -- -------------  Current Time:  60915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 60915);
                CHECK_VIDOUT_GREEN("0000000000", 60915);
                CHECK_VIDOUT_RED("0000000000", 60915);
                -- -------------------------------------
                -- -------------  Current Time:  61315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 61315);
                CHECK_VIDOUT_GREEN("1111111111", 61315);
                CHECK_VIDOUT_RED("1111111111", 61315);
                -- -------------------------------------
                -- -------------  Current Time:  61915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 61915);
                CHECK_VIDOUT_GREEN("0000000000", 61915);
                CHECK_VIDOUT_RED("0000000000", 61915);
                -- -------------------------------------
                -- -------------  Current Time:  62315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 62315);
                CHECK_VIDOUT_GREEN("1111111111", 62315);
                CHECK_VIDOUT_RED("1111111111", 62315);
                -- -------------------------------------
                -- -------------  Current Time:  62515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 62515);
                CHECK_VIDOUT_GREEN("0000000000", 62515);
                CHECK_VIDOUT_RED("0000000000", 62515);
                -- -------------------------------------
                -- -------------  Current Time:  62915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 62915);
                CHECK_VIDOUT_GREEN("1111111111", 62915);
                CHECK_VIDOUT_RED("1111111111", 62915);
                -- -------------------------------------
                -- -------------  Current Time:  63515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 63515);
                CHECK_VIDOUT_GREEN("0000000000", 63515);
                CHECK_VIDOUT_RED("0000000000", 63515);
                -- -------------------------------------
                -- -------------  Current Time:  63915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 63915);
                CHECK_VIDOUT_GREEN("1111111111", 63915);
                CHECK_VIDOUT_RED("1111111111", 63915);
                -- -------------------------------------
                -- -------------  Current Time:  64115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 64115);
                CHECK_VIDOUT_GREEN("0000000000", 64115);
                CHECK_VIDOUT_RED("0000000000", 64115);
                -- -------------------------------------
                -- -------------  Current Time:  64515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 64515);
                CHECK_VIDOUT_GREEN("1111111111", 64515);
                CHECK_VIDOUT_RED("1111111111", 64515);
                -- -------------------------------------
                -- -------------  Current Time:  65115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 65115);
                CHECK_VIDOUT_GREEN("0000000000", 65115);
                CHECK_VIDOUT_RED("0000000000", 65115);
                -- -------------------------------------
                -- -------------  Current Time:  65515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 65515);
                CHECK_VIDOUT_GREEN("1111111111", 65515);
                CHECK_VIDOUT_RED("1111111111", 65515);
                -- -------------------------------------
                -- -------------  Current Time:  65715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 65715);
                CHECK_VIDOUT_GREEN("0000000000", 65715);
                CHECK_VIDOUT_RED("0000000000", 65715);
                -- -------------------------------------
                -- -------------  Current Time:  66115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 66115);
                CHECK_VIDOUT_GREEN("1111111111", 66115);
                CHECK_VIDOUT_RED("1111111111", 66115);
                -- -------------------------------------
                -- -------------  Current Time:  66715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 66715);
                CHECK_VIDOUT_GREEN("0000000000", 66715);
                CHECK_VIDOUT_RED("0000000000", 66715);
                -- -------------------------------------
                -- -------------  Current Time:  67115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 67115);
                CHECK_VIDOUT_GREEN("1111111111", 67115);
                CHECK_VIDOUT_RED("1111111111", 67115);
                -- -------------------------------------
                -- -------------  Current Time:  67315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 67315);
                CHECK_VIDOUT_GREEN("0000000000", 67315);
                CHECK_VIDOUT_RED("0000000000", 67315);
                -- -------------------------------------
                -- -------------  Current Time:  67715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 67715);
                CHECK_VIDOUT_GREEN("1111111111", 67715);
                CHECK_VIDOUT_RED("1111111111", 67715);
                -- -------------------------------------
                -- -------------  Current Time:  68315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 68315);
                CHECK_VIDOUT_GREEN("0000000000", 68315);
                CHECK_VIDOUT_RED("0000000000", 68315);
                -- -------------------------------------
                -- -------------  Current Time:  68715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 68715);
                CHECK_VIDOUT_GREEN("1111111111", 68715);
                CHECK_VIDOUT_RED("1111111111", 68715);
                -- -------------------------------------
                -- -------------  Current Time:  68915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 68915);
                CHECK_VIDOUT_GREEN("0000000000", 68915);
                CHECK_VIDOUT_RED("0000000000", 68915);
                -- -------------------------------------
                -- -------------  Current Time:  69315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 69315);
                CHECK_VIDOUT_GREEN("1111111111", 69315);
                CHECK_VIDOUT_RED("1111111111", 69315);
                -- -------------------------------------
                -- -------------  Current Time:  69915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 69915);
                CHECK_VIDOUT_GREEN("0000000000", 69915);
                CHECK_VIDOUT_RED("0000000000", 69915);
                -- -------------------------------------
                -- -------------  Current Time:  70315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 70315);
                CHECK_VIDOUT_GREEN("1111111111", 70315);
                CHECK_VIDOUT_RED("1111111111", 70315);
                -- -------------------------------------
                -- -------------  Current Time:  70515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 70515);
                CHECK_VIDOUT_GREEN("0000000000", 70515);
                CHECK_VIDOUT_RED("0000000000", 70515);
                -- -------------------------------------
                -- -------------  Current Time:  70915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 70915);
                CHECK_VIDOUT_GREEN("1111111111", 70915);
                CHECK_VIDOUT_RED("1111111111", 70915);
                -- -------------------------------------
                -- -------------  Current Time:  71515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 71515);
                CHECK_VIDOUT_GREEN("0000000000", 71515);
                CHECK_VIDOUT_RED("0000000000", 71515);
                -- -------------------------------------
                -- -------------  Current Time:  71915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 71915);
                CHECK_VIDOUT_GREEN("1111111111", 71915);
                CHECK_VIDOUT_RED("1111111111", 71915);
                -- -------------------------------------
                -- -------------  Current Time:  72115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 72115);
                CHECK_VIDOUT_GREEN("0000000000", 72115);
                CHECK_VIDOUT_RED("0000000000", 72115);
                -- -------------------------------------
                -- -------------  Current Time:  72515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 72515);
                CHECK_VIDOUT_GREEN("1111111111", 72515);
                CHECK_VIDOUT_RED("1111111111", 72515);
                -- -------------------------------------
                -- -------------  Current Time:  73115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 73115);
                CHECK_VIDOUT_GREEN("0000000000", 73115);
                CHECK_VIDOUT_RED("0000000000", 73115);
                -- -------------------------------------
                -- -------------  Current Time:  73515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 73515);
                CHECK_VIDOUT_GREEN("1111111111", 73515);
                CHECK_VIDOUT_RED("1111111111", 73515);
                -- -------------------------------------
                -- -------------  Current Time:  73715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 73715);
                CHECK_VIDOUT_GREEN("0000000000", 73715);
                CHECK_VIDOUT_RED("0000000000", 73715);
                -- -------------------------------------
                -- -------------  Current Time:  74115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 74115);
                CHECK_VIDOUT_GREEN("1111111111", 74115);
                CHECK_VIDOUT_RED("1111111111", 74115);
                -- -------------------------------------
                -- -------------  Current Time:  74715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 74715);
                CHECK_VIDOUT_GREEN("0000000000", 74715);
                CHECK_VIDOUT_RED("0000000000", 74715);
                -- -------------------------------------
                -- -------------  Current Time:  75115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 75115);
                CHECK_VIDOUT_GREEN("1111111111", 75115);
                CHECK_VIDOUT_RED("1111111111", 75115);
                -- -------------------------------------
                -- -------------  Current Time:  75315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 75315);
                CHECK_VIDOUT_GREEN("0000000000", 75315);
                CHECK_VIDOUT_RED("0000000000", 75315);
                -- -------------------------------------
                -- -------------  Current Time:  75715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 75715);
                CHECK_VIDOUT_GREEN("1111111111", 75715);
                CHECK_VIDOUT_RED("1111111111", 75715);
                -- -------------------------------------
                -- -------------  Current Time:  76315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 76315);
                CHECK_VIDOUT_GREEN("0000000000", 76315);
                CHECK_VIDOUT_RED("0000000000", 76315);
                -- -------------------------------------
                -- -------------  Current Time:  76715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 76715);
                CHECK_VIDOUT_GREEN("1111111111", 76715);
                CHECK_VIDOUT_RED("1111111111", 76715);
                -- -------------------------------------
                -- -------------  Current Time:  76915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 76915);
                CHECK_VIDOUT_GREEN("0000000000", 76915);
                CHECK_VIDOUT_RED("0000000000", 76915);
                -- -------------------------------------
                -- -------------  Current Time:  77315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 77315);
                CHECK_VIDOUT_GREEN("1111111111", 77315);
                CHECK_VIDOUT_RED("1111111111", 77315);
                -- -------------------------------------
                -- -------------  Current Time:  77915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 77915);
                CHECK_VIDOUT_GREEN("0000000000", 77915);
                CHECK_VIDOUT_RED("0000000000", 77915);
                -- -------------------------------------
                -- -------------  Current Time:  78315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 78315);
                CHECK_VIDOUT_GREEN("1111111111", 78315);
                CHECK_VIDOUT_RED("1111111111", 78315);
                -- -------------------------------------
                -- -------------  Current Time:  78515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 78515);
                CHECK_VIDOUT_GREEN("0000000000", 78515);
                CHECK_VIDOUT_RED("0000000000", 78515);
                -- -------------------------------------
                -- -------------  Current Time:  78915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 78915);
                CHECK_VIDOUT_GREEN("1111111111", 78915);
                CHECK_VIDOUT_RED("1111111111", 78915);
                -- -------------------------------------
                -- -------------  Current Time:  79515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 79515);
                CHECK_VIDOUT_GREEN("0000000000", 79515);
                CHECK_VIDOUT_RED("0000000000", 79515);
                -- -------------------------------------
                -- -------------  Current Time:  79915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 79915);
                CHECK_VIDOUT_GREEN("1111111111", 79915);
                CHECK_VIDOUT_RED("1111111111", 79915);
                -- -------------------------------------
                -- -------------  Current Time:  80115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 80115);
                CHECK_VIDOUT_GREEN("0000000000", 80115);
                CHECK_VIDOUT_RED("0000000000", 80115);
                -- -------------------------------------
                -- -------------  Current Time:  80515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 80515);
                CHECK_VIDOUT_GREEN("1111111111", 80515);
                CHECK_VIDOUT_RED("1111111111", 80515);
                -- -------------------------------------
                -- -------------  Current Time:  81115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 81115);
                CHECK_VIDOUT_GREEN("0000000000", 81115);
                CHECK_VIDOUT_RED("0000000000", 81115);
                -- -------------------------------------
                -- -------------  Current Time:  81515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 81515);
                CHECK_VIDOUT_GREEN("1111111111", 81515);
                CHECK_VIDOUT_RED("1111111111", 81515);
                -- -------------------------------------
                -- -------------  Current Time:  81715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 81715);
                CHECK_VIDOUT_GREEN("0000000000", 81715);
                CHECK_VIDOUT_RED("0000000000", 81715);
                -- -------------------------------------
                -- -------------  Current Time:  82115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 82115);
                CHECK_VIDOUT_GREEN("1111111111", 82115);
                CHECK_VIDOUT_RED("1111111111", 82115);
                -- -------------------------------------
                -- -------------  Current Time:  82715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 82715);
                CHECK_VIDOUT_GREEN("0000000000", 82715);
                CHECK_VIDOUT_RED("0000000000", 82715);
                -- -------------------------------------
                -- -------------  Current Time:  83115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 83115);
                CHECK_VIDOUT_GREEN("1111111111", 83115);
                CHECK_VIDOUT_RED("1111111111", 83115);
                -- -------------------------------------
                -- -------------  Current Time:  83315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 83315);
                CHECK_VIDOUT_GREEN("0000000000", 83315);
                CHECK_VIDOUT_RED("0000000000", 83315);
                -- -------------------------------------
                -- -------------  Current Time:  83715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 83715);
                CHECK_VIDOUT_GREEN("1111111111", 83715);
                CHECK_VIDOUT_RED("1111111111", 83715);
                -- -------------------------------------
                -- -------------  Current Time:  84315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 84315);
                CHECK_VIDOUT_GREEN("0000000000", 84315);
                CHECK_VIDOUT_RED("0000000000", 84315);
                -- -------------------------------------
                -- -------------  Current Time:  84715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 84715);
                CHECK_VIDOUT_GREEN("1111111111", 84715);
                CHECK_VIDOUT_RED("1111111111", 84715);
                -- -------------------------------------
                -- -------------  Current Time:  84915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 84915);
                CHECK_VIDOUT_GREEN("0000000000", 84915);
                CHECK_VIDOUT_RED("0000000000", 84915);
                -- -------------------------------------
                -- -------------  Current Time:  85315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 85315);
                CHECK_VIDOUT_GREEN("1111111111", 85315);
                CHECK_VIDOUT_RED("1111111111", 85315);
                -- -------------------------------------
                -- -------------  Current Time:  85915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 85915);
                CHECK_VIDOUT_GREEN("0000000000", 85915);
                CHECK_VIDOUT_RED("0000000000", 85915);
                -- -------------------------------------
                -- -------------  Current Time:  86315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 86315);
                CHECK_VIDOUT_GREEN("1111111111", 86315);
                CHECK_VIDOUT_RED("1111111111", 86315);
                -- -------------------------------------
                -- -------------  Current Time:  86515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 86515);
                CHECK_VIDOUT_GREEN("0000000000", 86515);
                CHECK_VIDOUT_RED("0000000000", 86515);
                -- -------------------------------------
                -- -------------  Current Time:  86915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 86915);
                CHECK_VIDOUT_GREEN("1111111111", 86915);
                CHECK_VIDOUT_RED("1111111111", 86915);
                -- -------------------------------------
                -- -------------  Current Time:  87515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 87515);
                CHECK_VIDOUT_GREEN("0000000000", 87515);
                CHECK_VIDOUT_RED("0000000000", 87515);
                -- -------------------------------------
                -- -------------  Current Time:  87915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 87915);
                CHECK_VIDOUT_GREEN("1111111111", 87915);
                CHECK_VIDOUT_RED("1111111111", 87915);
                -- -------------------------------------
                -- -------------  Current Time:  88115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 88115);
                CHECK_VIDOUT_GREEN("0000000000", 88115);
                CHECK_VIDOUT_RED("0000000000", 88115);
                -- -------------------------------------
                -- -------------  Current Time:  88515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 88515);
                CHECK_VIDOUT_GREEN("1111111111", 88515);
                CHECK_VIDOUT_RED("1111111111", 88515);
                -- -------------------------------------
                -- -------------  Current Time:  89115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 89115);
                CHECK_VIDOUT_GREEN("0000000000", 89115);
                CHECK_VIDOUT_RED("0000000000", 89115);
                -- -------------------------------------
                -- -------------  Current Time:  89515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 89515);
                CHECK_VIDOUT_GREEN("1111111111", 89515);
                CHECK_VIDOUT_RED("1111111111", 89515);
                -- -------------------------------------
                -- -------------  Current Time:  89715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 89715);
                CHECK_VIDOUT_GREEN("0000000000", 89715);
                CHECK_VIDOUT_RED("0000000000", 89715);
                -- -------------------------------------
                -- -------------  Current Time:  90115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 90115);
                CHECK_VIDOUT_GREEN("1111111111", 90115);
                CHECK_VIDOUT_RED("1111111111", 90115);
                -- -------------------------------------
                -- -------------  Current Time:  90715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 90715);
                CHECK_VIDOUT_GREEN("0000000000", 90715);
                CHECK_VIDOUT_RED("0000000000", 90715);
                -- -------------------------------------
                -- -------------  Current Time:  91115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 91115);
                CHECK_VIDOUT_GREEN("1111111111", 91115);
                CHECK_VIDOUT_RED("1111111111", 91115);
                -- -------------------------------------
                -- -------------  Current Time:  91315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 91315);
                CHECK_VIDOUT_GREEN("0000000000", 91315);
                CHECK_VIDOUT_RED("0000000000", 91315);
                -- -------------------------------------
                -- -------------  Current Time:  91715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 91715);
                CHECK_VIDOUT_GREEN("1111111111", 91715);
                CHECK_VIDOUT_RED("1111111111", 91715);
                -- -------------------------------------
                -- -------------  Current Time:  92315ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 92315);
                CHECK_VIDOUT_GREEN("0000000000", 92315);
                CHECK_VIDOUT_RED("0000000000", 92315);
                -- -------------------------------------
                -- -------------  Current Time:  92715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 92715);
                CHECK_VIDOUT_GREEN("1111111111", 92715);
                CHECK_VIDOUT_RED("1111111111", 92715);
                -- -------------------------------------
                -- -------------  Current Time:  92915ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 92915);
                CHECK_VIDOUT_GREEN("0000000000", 92915);
                CHECK_VIDOUT_RED("0000000000", 92915);
                -- -------------------------------------
                -- -------------  Current Time:  93315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 93315);
                CHECK_VIDOUT_GREEN("1111111111", 93315);
                CHECK_VIDOUT_RED("1111111111", 93315);
                -- -------------------------------------
                -- -------------  Current Time:  93915ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 93915);
                CHECK_VIDOUT_GREEN("0000000000", 93915);
                CHECK_VIDOUT_RED("0000000000", 93915);
                -- -------------------------------------
                -- -------------  Current Time:  94315ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 94315);
                CHECK_VIDOUT_GREEN("1111111111", 94315);
                CHECK_VIDOUT_RED("1111111111", 94315);
                -- -------------------------------------
                -- -------------  Current Time:  94515ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 94515);
                CHECK_VIDOUT_GREEN("0000000000", 94515);
                CHECK_VIDOUT_RED("0000000000", 94515);
                -- -------------------------------------
                -- -------------  Current Time:  94915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 94915);
                CHECK_VIDOUT_GREEN("1111111111", 94915);
                CHECK_VIDOUT_RED("1111111111", 94915);
                -- -------------------------------------
                -- -------------  Current Time:  95515ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 95515);
                CHECK_VIDOUT_GREEN("0000000000", 95515);
                CHECK_VIDOUT_RED("0000000000", 95515);
                -- -------------------------------------
                -- -------------  Current Time:  95915ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 95915);
                CHECK_VIDOUT_GREEN("1111111111", 95915);
                CHECK_VIDOUT_RED("1111111111", 95915);
                -- -------------------------------------
                -- -------------  Current Time:  96115ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 96115);
                CHECK_VIDOUT_GREEN("0000000000", 96115);
                CHECK_VIDOUT_RED("0000000000", 96115);
                -- -------------------------------------
                -- -------------  Current Time:  96515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 96515);
                CHECK_VIDOUT_GREEN("1111111111", 96515);
                CHECK_VIDOUT_RED("1111111111", 96515);
                -- -------------------------------------
                -- -------------  Current Time:  97115ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 97115);
                CHECK_VIDOUT_GREEN("0000000000", 97115);
                CHECK_VIDOUT_RED("0000000000", 97115);
                -- -------------------------------------
                -- -------------  Current Time:  97515ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 97515);
                CHECK_VIDOUT_GREEN("1111111111", 97515);
                CHECK_VIDOUT_RED("1111111111", 97515);
                -- -------------------------------------
                -- -------------  Current Time:  97715ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 97715);
                CHECK_VIDOUT_GREEN("0000000000", 97715);
                CHECK_VIDOUT_RED("0000000000", 97715);
                -- -------------------------------------
                -- -------------  Current Time:  98115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 98115);
                CHECK_VIDOUT_GREEN("1111111111", 98115);
                CHECK_VIDOUT_RED("1111111111", 98115);
                -- -------------------------------------
                -- -------------  Current Time:  98715ns
                WAIT FOR 600 ns;
                CHECK_VIDOUT_BLUE("0000000000", 98715);
                CHECK_VIDOUT_GREEN("0000000000", 98715);
                CHECK_VIDOUT_RED("0000000000", 98715);
                -- -------------------------------------
                -- -------------  Current Time:  99115ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 99115);
                CHECK_VIDOUT_GREEN("1111111111", 99115);
                CHECK_VIDOUT_RED("1111111111", 99115);
                -- -------------------------------------
                -- -------------  Current Time:  99315ns
                WAIT FOR 200 ns;
                CHECK_VIDOUT_BLUE("0000000000", 99315);
                CHECK_VIDOUT_GREEN("0000000000", 99315);
                CHECK_VIDOUT_RED("0000000000", 99315);
                -- -------------------------------------
                -- -------------  Current Time:  99715ns
                WAIT FOR 400 ns;
                CHECK_VIDOUT_BLUE("1111111111", 99715);
                CHECK_VIDOUT_GREEN("1111111111", 99715);
                CHECK_VIDOUT_RED("1111111111", 99715);
                -- -------------------------------------
                WAIT FOR 485 ns;

                IF (TX_ERROR = 0) THEN
                    STD.TEXTIO.write(TX_OUT, string'("No errors or warnings"));
                    STD.TEXTIO.writeline(RESULTS, TX_OUT);
                    ASSERT (FALSE) REPORT
                      "Simulation successful (not a failure).  No problems detected."
                      SEVERITY FAILURE;
                ELSE
                    STD.TEXTIO.write(TX_OUT, TX_ERROR);
                    STD.TEXTIO.write(TX_OUT,
                        string'(" errors found in simulation"));
                    STD.TEXTIO.writeline(RESULTS, TX_OUT);
                    ASSERT (FALSE) REPORT "Errors found during simulation"
                         SEVERITY FAILURE;
                END IF;
            END PROCESS;

    END testbench_arch;

